DefaultAuthTheme class

Default theme for all Firebase Auth screens.

You can override this theme using your own styles.

Inheritance

Constructors

DefaultAuthTheme({Key? key, required Widget child, Color backgroundColor = Colors.white, EdgeInsets padding = const EdgeInsets.all(24), InputDecoration inputDecoration = const InputDecoration(filled: true, fillColor: Color(0x1F5F5F87), border: OutlineInputBorder(borderRadius: BorderRadius.all(Radius.circular(30)))), ButtonStyle primaryButtonStyle = const ButtonStyle(backgroundColor: WidgetStatePropertyAll(Colors.teal), foregroundColor: WidgetStatePropertyAll(Colors.white), shape: WidgetStatePropertyAll(RoundedRectangleBorder(borderRadius: BorderRadius.all(Radius.circular(30))))), TextStyle primaryButtonTextStyle = const TextStyle(fontSize: 18, fontWeight: FontWeight.bold), TextStyle linkStyle = const TextStyle(color: Colors.blue), TextStyle errorTextStyle = const TextStyle(color: Colors.red), TextStyle infoTextStyle = const TextStyle(color: Colors.teal), TextStyle titleStyle = const TextStyle(fontSize: 24, fontWeight: FontWeight.bold), })
Creates a DefaultAuthTheme widget that provides default styling for auth screens.
const

Properties

backgroundColor Color
The background color for the authentication screens.
final
child Widget
The widget below this widget in the tree.
finalinherited
errorTextStyle TextStyle
The text style for error messages.
final
hashCode int
The hash code for this object.
no setterinherited
infoTextStyle TextStyle
The text style for informational messages.
final
inputDecoration InputDecoration
The decoration used for input fields.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
linkStyle TextStyle
The text style for clickable links.
final
An optional logo widget displayed at the top of authentication screens.
final
padding EdgeInsets
The padding applied around the authentication content.
final
primaryButtonStyle ButtonStyle
The style applied to primary buttons.
final
primaryButtonTextStyle TextStyle
The text style for primary buttons.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleStyle TextStyle
The text style for screen titles.
final

Methods

createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant InheritedWidget oldWidget) bool
Whether the widget should notify dependents when updated. Always returns false.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext ctx) DefaultAuthTheme
Returns the nearest DefaultAuthTheme up the widget tree.